<?php

declare(strict_types=1);

namespace Drupal\symfony_http_client;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Definition;
use Symfony\Component\HttpClient\HttpClient;
use Symfony\Contracts\HttpClient\HttpClientInterface;

/**
 * Symfony HTTP Client compiler pass.
 *
 * These things happen here rather than YAML so no code relies on the factory.
 */
final class SymfonyHttpClientCompilerPass implements CompilerPassInterface {

  public function process(ContainerBuilder $container): void {
    $id = ContainerBuilder::hash(\sprintf('symfony_http_client.factory%s', \mt_rand()));
    $container->setAlias(HttpClientInterface::class, $id);
    $container->setDefinition(
      $id,
      (new Definition(HttpClient::class))
        ->setFactory([HttpClient::class, 'create'])
        ->setPublic(FALSE),
    );
  }

}
